@@ -12,7 +12,7 @@ require XSLoader;
 use vars qw/$VERSION/;
 
 BEGIN {
-    our $VERSION = '1.0.48'; # VERSION
+    our $VERSION = '1.0.49'; # VERSION
 
     XSLoader::load __PACKAGE__, $VERSION;
 }
@@ -31,7 +31,7 @@ MarpaX::ESLIF - ESLIF is Extended ScanLess InterFace
 
 =head1 VERSION
 
-version 1.0.48
+version 1.0.49
 
 =head1 SYNOPSIS
 
@@ -47,12 +47,6 @@ ESLIF is an extension of perl's L<Marpa::R2> BNF, written as a stand-alone L<mar
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
 
-=head1 CONTRIBUTOR
-
-=for stopwords Jean-Damien Durand
-
-Jean-Damien Durand <Jean-Damien.Durand@fisglobal.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Jean-Damien Durand.
